Turn off the 'public' check for main, and improve diagnostics.

We're likely to be able to invoke a static main method before we can invoke
a virtual getModifiers, and right now we don't care whether we've been asked
to run a non-public main.

Also adds PrettyMethod for improved diagnostics.

Change-Id: Iea08f0be980386adbe408b476449c2066c4e6da8
diff --git a/src/utils.h b/src/utils.h
index ea51d1e..541fbfa 100644
--- a/src/utils.h
+++ b/src/utils.h
@@ -10,6 +10,7 @@
 
 namespace art {
 
+class Method;
 class Object;
 
 template<typename T>
@@ -135,13 +136,17 @@
   return result;
 }
 
-// Return a newly-allocated string containing a human-readable equivalent
-// of 'descriptor'. So "I" would be "int", "[[I" would be "int[][]",
-// "[Ljava/lang/String;" would be "java.lang.String[]", and so forth.
+// Returns a human-readable equivalent of 'descriptor'. So "I" would be "int",
+// "[[I" would be "int[][]", "[Ljava/lang/String;" would be
+// "java.lang.String[]", and so forth.
 std::string PrettyDescriptor(const StringPiece& descriptor);
 
-// Returns a human-readable string form of the name of the class of
-// the given object. So given a java.lang.String, the output would
+// Returns a human-readable signature for 'm'. Something like "a.b.C.m" or
+// "a.b.C.m(II)V" (depending on the value of 'with_signature').
+std::string PrettyMethod(const Method* m, bool with_signature);
+
+// Returns a human-readable form of the name of the *class* of the given object.
+// So given an instance of java.lang.String, the output would
 // be "java.lang.String". Given an array of int, the output would be "int[]".
 // Given String.class, the output would be "java.lang.Class<java.lang.String>".
 std::string PrettyType(const Object* obj);